@@ -467,7 +467,7 @@ class Request:
 
         while downloaded < self.content_length:
             _start = downloaded
-            _end = min(downloaded + chunk_size - 1, self.total_size - 1)
+            _end = min(downloaded + chunk_size - 1, self.content_length - 1)
             detect_settings.setdefault("headers", {})['Range'] = f"bytes={_start}-{_end}"
 
             self.response = requests.request(
@@ -481,7 +481,7 @@ class Request:
                 yield chunk_data
                 downloaded += len(chunk_data)
                 retry_count = 0  # 重置重试计数
-                logging.info(f"下载进度: {downloaded}/{self.total_size} ({downloaded / self.total_size * 100:.1f}%)")
+                logging.info(f"下载进度: {downloaded}/{self.content_length} ({downloaded / self.content_length * 100:.1f}%)")
 
             elif self.response.status_code == 416:  # Range Not Satisfiable
                 logging.info("Range请求超出范围")
@@ -585,7 +585,7 @@ class Request:
 
     @property
     def to_dict(self) -> Dict[str, Any]:
-        excluded_keys = {"request_settings", "url", "seed", "method", "check_status_code"}
+        excluded_keys = {"request_settings", "url", "seed", "method", "response", "check_status_code"}
         result = {
             key: value for key, value in self.__dict__.items()
             if not key.startswith('_') and key not in excluded_keys
